pub struct NFTokenTransferProcessProgress {
pub data_manipulation: NFTokenDataManipulationProgress,
pub done: bool,
pub success: Option<bool>,
pub error: Option<NFTokenRetrievalProcessError>,
pub finish_date: Option<UtcDateTime>,
}Expand description
Report on the asynchronous processing status of a non-fungible token transfer.
Fields
data_manipulation: NFTokenDataManipulationProgressProgress of the non-fungible token data manipulation: reading and rewriting it after re-encryption (if required).
done: boolIndicates whether the processing has been finished.
success: Option<bool>Indicates whether the non-fungible token has been successfully transferred.
Note: only returned if the processing has already been finished.
error: Option<NFTokenRetrievalProcessError>Processing error.
Note: only returned if the processing finished with error.
finish_date: Option<UtcDateTime>Date and time when the non-fungible token transfer has been finalized.
Note: only returned if the processing has already been finished.