pub struct Error { /* private fields */ }Expand description
Represents an error that took place when calling a Catenis API client function.
That error can be of two different types:
Client error
An error that takes place in the client itself, and could be of many different kinds.
Catenis API error
A response returned by the Catenis API server reporting an error condition while processing the client request.
Example
// Simulate a Catenis API error trying to read a message with an invalid message ID
let error = ctn_client.read_message("xxxxx", None).err().unwrap();
assert!(error.is_api_error());
let api_error = error.api_error_info().unwrap();
assert_eq!(api_error.status_code(), 400);
assert_eq!(api_error.status_message().unwrap(), "Bad Request");
assert_eq!(api_error.catenis_message().unwrap(), "[400] - Invalid message ID");
assert_eq!(error.to_string(), "Catenis API error: [400] - Invalid message ID");Implementations
Sourceimpl Error
impl Error
Sourcepub fn is_api_error(&self) -> bool
pub fn is_api_error(&self) -> bool
Indicates whether this is a Catenis API error.
Sourcepub fn api_error_info(&self) -> Option<&ApiErrorInfo>
pub fn api_error_info(&self) -> Option<&ApiErrorInfo>
Retrieves information about the Catenis API error.